==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataBindingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataBindingEventArgsDescription } from "./DataBindingEventArgsDescription";
/**
 * @hidden
 */
var DataBindingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataBindingEventArgsDescriptionMetadata, _super);
    function DataBindingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataBindingEventArgsDescriptionMetadata.b = function (a) {
        if (DataBindingEventArgsDescriptionMetadata.a == null) {
            DataBindingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataBindingEventArgsDescriptionMetadata.c(DataBindingEventArgsDescriptionMetadata.a);
        }
        if (a.g(DataBindingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(DataBindingEventArgsDescriptionMetadata.a);
    };
    DataBindingEventArgsDescriptionMetadata.c = function (a) {
        a.item("ResolvedValueRef", "(w:ResolvedValue,wf:ResolvedValue)DataRef");
        a.item("RowObjectRef", "(w:RowObject,wf:RowObject)DataRef");
    };
    DataBindingEventArgsDescriptionMetadata.d = function (a) {
        DataBindingEventArgsDescriptionMetadata.b(a);
        a.u("DataBindingEventArgs", function () { return new DataBindingEventArgsDescription(); });
        a.t("DataBindingEventArgs", DataBindingEventArgsDescriptionMetadata.a);
    };
    DataBindingEventArgsDescriptionMetadata.$t = markType(DataBindingEventArgsDescriptionMetadata, 'DataBindingEventArgsDescriptionMetadata');
    DataBindingEventArgsDescriptionMetadata.a = null;
    return DataBindingEventArgsDescriptionMetadata;
}(Base));
export { DataBindingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataBindingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataBindingEventArgsDescription } from "./DataBindingEventArgsDescription";
/**
 * @hidden
 */
var DataBindingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataBindingEventArgsDescriptionMetadata, _super);
    function DataBindingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataBindingEventArgsDescriptionMetadata.b = function (a) {
        if (DataBindingEventArgsDescriptionMetadata.a == null) {
            DataBindingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataBindingEventArgsDescriptionMetadata.c(DataBindingEventArgsDescriptionMetadata.a);
        }
        if (a.j(DataBindingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DataBindingEventArgsDescriptionMetadata.a);
    };
    DataBindingEventArgsDescriptionMetadata.c = function (a) {
        a.item("ResolvedValueRef", "(w:ResolvedValue,wf:ResolvedValue)DataRef");
        a.item("RowObjectRef", "(w:RowObject,wf:RowObject)DataRef");
    };
    DataBindingEventArgsDescriptionMetadata.d = function (a) {
        DataBindingEventArgsDescriptionMetadata.b(a);
        a.aa("DataBindingEventArgs", function () { return new DataBindingEventArgsDescription(); });
        a.z("DataBindingEventArgs", DataBindingEventArgsDescriptionMetadata.a);
    };
    DataBindingEventArgsDescriptionMetadata.$t = markType(DataBindingEventArgsDescriptionMetadata, 'DataBindingEventArgsDescriptionMetadata');
    DataBindingEventArgsDescriptionMetadata.a = null;
    return DataBindingEventArgsDescriptionMetadata;
}(Base));
export { DataBindingEventArgsDescriptionMetadata };
